# Things and People that have helped this project.

Firstly thanks to [0x.se](https://0x.se/) for paying me to work as a software developer so I can build things like this.

## Early feedback
Thanks for early feedback on the documentation and design go to Mohammed, Henrink, Tony, Alan, Jaimal and Debo.

## Contributors
  * @BrentSouza
  * @MisterKeefe
